@@ -103,7 +103,7 @@
 #undef  LOCK_SH
 #endif
 
-#ifdef  MACOSX
+#if defined(MACOSX) || defined(__ANDROID__)
 #define MISSING_LOCKF
 #endif
 
@@ -119,6 +119,10 @@ enum {
 
 #endif
 
+#if defined(MISSING_LOCKF)
+#define lockf(a, b, c) flock(a, b)
+#endif
+
 #endif // ndef WIN32
 
 #if defined(_OSF_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE > 1
