@@ -51,7 +51,7 @@
 #include <commoncpp/socket.h>
 #endif
 
-NAMESPACE_COMMONCPP
+namespace ost {
 
 class MIMEMultipart;
 class MIMEItemPart;
@@ -105,7 +105,7 @@ public:
      * @return array of headers.
      */
     char **getHeaders(void)
-        {return header;};
+        {return header;}
 };
 
 /**
@@ -211,12 +211,6 @@ public:
     MIMEFormData(MIMEMultipartForm *top, const char *name, const char *content);
 };
 
-END_NAMESPACE
+} // namespace ost
 
 #endif
-/** EMACS **
- * Local variables:
- * mode: c++
- * c-basic-offset: 4
- * End:
- */
