@@ -17,10 +17,12 @@
 
 #include "local.h"
 
+namespace ucommon {
+
 SSLBuffer::SSLBuffer(secure::client_t scontext) :
 TCPBuffer()
 {
-    context *ctx = (context *)scontext;
+    __context *ctx = (__context *)scontext;
     ssl = NULL;
     bio = NULL;
     server = false;
@@ -32,7 +34,7 @@ TCPBuffer()
 SSLBuffer::SSLBuffer(const TCPServer *tcp, secure::server_t scontext, size_t size) :
 TCPBuffer(tcp, size)
 {
-    context *ctx = (context *)scontext;
+    __context *ctx = (__context *)scontext;
     ssl = NULL;
     bio = NULL;
     server = true;
@@ -162,3 +164,4 @@ bool SSLBuffer::_flush(void)
     return false;
 }
 
+} // namespace ucommon
