@@ -18,7 +18,7 @@
 #include <ucommon/secure.h>
 #include <sys/stat.h>
 
-using namespace UCOMMON_NAMESPACE;
+using namespace ucommon;
 
 static shell::flagopt helpflag('h',"--help",    _TEXT("display this list"));
 static shell::flagopt althelp('?', NULL, NULL);
